# -*- coding: utf-8 -*-

import json
import kola.connection
from kola.utils import safe_call

from kola.vals import logger


class Connection(kola.connection.Connection):
    def _read_message(self):
        if not self.stream.closed():
            self.stream.readline(self._on_read_complete)
